@@ -84,8 +84,10 @@ def text(obj, carryForward=None):
     if obj.get('marks'):
         #Search for Marks
         for m in obj.get("marks"):
-            try: text += parse(m)
-            except: pass
+            try: text += parse(m)                          #Since marks are not in 'switcher' this will throw error which will be handled in next line and as a result, we'll get a blank
+            except:
+                print("Unable to parse Marks") 
+                pass
     return text
 
 def link(attrs, carryForward=None):
@@ -104,11 +106,8 @@ def hardBreak(data=None, carryForward=None):
     print("Parsing HardBreak")
     return '\n'
 
-
-#Driver Functions
-def parse(adf, carryForward=None, debug=False):
-    if debug==False: blockPrint()
-    switcher = {
+#Driver Dependencies
+switcher = {
         "doc": (doc, 'content'),
         "blockquote": (blockquote, 'content'),
         "paragraph": (paragraph, 'content'),
@@ -121,18 +120,26 @@ def parse(adf, carryForward=None, debug=False):
         "heading": (heading, 'content'),
         "link": (link, 'attrs'),
         "mention": (mention, 'attrs'),                          #Available only with type="text"
-        "emoji": (emoji, 'attrs')
+        "emoji": (emoji, 'attrs')                               #Available only with type="text"        
     }
-    replacers = ["\n\n\n\n", "\n\n\n", "\n\n"]
+replacers = ["\n\n\n\n", "\n\n\n", "\n\n"]
+
+
+#Driver Functions
+def parse(adf, carryForward=None):    
     type=switcher.get(adf['type'])                              #Get the ADF Type | Ex: "paragraph"
     fn=type[0]                                                  #Get the Function | Ex: paragraph()
     data=adf if type[1]=="self" else adf.get(type[1], None)     #Get the data to parse | Ex: "content" or "attrs" or "text"
     try: 
-        result=fn(data, carryForward)                           #Ex: listItem(adf["content"], 1)
+        result=fn(data, carryForward)                           #Ex: listItem(adf["content"], 1)                
+        return result
+    except: return ''
+
+def startParsing(adf, debug=False, runReplacers=True):
+    if debug==False: blockPrint()                               #Check Debug before Start    
+    result = parse(adf)                                         #Do the Parsing
+    if runReplacers:                                            #Run Replacers
         for r in replacers:        
             result=result.replace(r, '\n')
-        enablePrint()
-        return result
-    except: 
-        enablePrint()
-        return ''
+    if debug==False: enablePrint()                              #Check Debug before Ending
+    return result                                               #Return result
